Module expr
spacetimedb_
query_
builder
2.0.1
Module expr
Module Items
Structs
Enums
Traits
Functions
In crate spacetimedb_
query_
builder
spacetimedb_query_builder
Module
expr
Structs

Literal
Value
Enums

Bool
Expr
Operand
Traits

RHS
Trait for types that can be used as the right-hand side of a comparison with a column of type V in table T.
Functions

format_
expr