RHS

Trait RHS 

pub trait RHS<T, V> {
    // Required method
    fn to_expr(self) -> Operand<T>;
}
Trait for types that can be used as the right-hand side of a comparison with a column of type V in table T.

This trait is implemented for Col<T, V> and various literal types.

Required Methods

fn to_expr(self) -> Operand<T>

Implementations on Foreign Types

Source

impl<T> RHS<T, &str> for &str

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, bool> for bool

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, f32> for f32

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, f64> for f64

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, i8> for i8

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, i16> for i16

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, i32> for i32

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, i64> for i64

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, i128> for i128

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, u8> for u8

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, u16> for u16

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, u32> for u32

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, u64> for u64

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, u128> for u128

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, usize> for usize

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, String> for String

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, Vec<u8>> for Vec<u8>

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, I256> for i256

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, U256> for u256

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, ConnectionId> for ConnectionId

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, Identity> for Identity

Source

fn to_expr(self) -> Operand<T>

Source

impl<T> RHS<T, Timestamp> for Timestamp

Source

fn to_expr(self) -> Operand<T>

Implementors

Source

impl<T, V> RHS<T, V> for Col<T, V>